@@ -8,12 +8,12 @@ SUBPROCESS_NAME='osmconvert'
 
 def get_osm_file_timestamp(input_path):
     command = [definitions.OSMCONVERT_PATH, '--out-timestamp', input_path, '--verbose']
-    return subprocess_get_stdout_output(command, SUBPROCESS_NAME)
+    return subprocess_get_stdout_output(args=command, subprocess_name=SUBPROCESS_NAME)
 
 def set_osm_file_timestamp(input_path, new_timestamp):
     (dir, name, _, input_format) = deconstruct_file_path(input_path)
     temp_path = os.path.join(dir, f'{str(uuid4())}.{input_format}')
-    run_command_wrapper(f'{definitions.OSMCONVERT_PATH} \
+    run_command_wrapper(command=f'{definitions.OSMCONVERT_PATH} \
                     {input_path} \
                     --timestamp={new_timestamp} \
                     -o={temp_path} \
@@ -30,11 +30,13 @@ def drop_author(input_path, output_path=None):
     if output_path is None:
         output_not_given = True
         output_path = os.path.join(input_dir, f'{str(uuid4())}.{input_format}')
-    run_command_wrapper(f'{definitions.OSMCONVERT_PATH} \
+    run_command_wrapper(command=f'{definitions.OSMCONVERT_PATH} \
                     --drop-author \
                     {input_path} \
                     -o={output_path} \
                     --verbose',
                     subprocess_name=SUBPROCESS_NAME)
     if output_not_given:
-        os.rename(output_path, input_path)
\ No newline at end of file
+        os.rename(output_path, input_path)
+        return input_path
+    return output_path
\ No newline at end of file
