@@ -1,4 +1,4 @@
-from cosmocrat.action_validators import validate_input_path, validate_output_path
+from cosmocrat.argument_parser.validation.action_validators import validate_input_path, validate_output_path
 from cosmocrat.osm_tools.osmconvert import drop_author
 
 def register_parser(sub_parser):
